function varargout = MaxLinksInWindowFigure(varargin)
% MAXLINKSINWINDOWFIGURE M-file for MaxLinksInWindowFigure.fig
%      MAXLINKSINWINDOWFIGURE, by itself, creates a new MAXLINKSINWINDOWFIGURE or raises the existing
%      singleton*.
%
%      H = MAXLINKSINWINDOWFIGURE returns the handle to a new MAXLINKSINWINDOWFIGURE or the handle to
%      the existing singleton*.
%
%      MAXLINKSINWINDOWFIGURE('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in MAXLINKSINWINDOWFIGURE.M with the given input arguments.
%
%      MAXLINKSINWINDOWFIGURE('Property','Value',...) creates a new MAXLINKSINWINDOWFIGURE or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before MaxLinksInWindowFigure_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to MaxLinksInWindowFigure_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help MaxLinksInWindowFigure

% Last Modified by GUIDE v2.5 11-Sep-2009 09:19:25

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @MaxLinksInWindowFigure_OpeningFcn, ...
                   'gui_OutputFcn',  @MaxLinksInWindowFigure_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

%========================================================================================================================
% --- Executes just before MaxLinksInWindowFigure is made visible.
function MaxLinksInWindowFigure_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to MaxLinksInWindowFigure (see VARARGIN)

% Choose default command line output for MaxLinksInWindowFigure
handles.output = hObject;

handles.baseFigure=varargin{1};

handles.plotFigure=figure;

% Update handles structure
guidata(hObject, handles);


% UIWAIT makes MaxLinksInWindowFigure wait for user response (see UIRESUME)
% uiwait(handles.figure1);

%========================================================================================================================
% --- Outputs from this function are returned to the command line.
function varargout = MaxLinksInWindowFigure_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

%========================================================================================================================
% --- Executes on button press in pushbuttonClose.
function pushbuttonClose_Callback(hObject, eventdata, handles)
% hObject    handle to pushbuttonClose (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

delete(handles.plotFigure);
delete(handles.figure1);

%========================================================================================================================
% --- Executes on button press in pushbuttonGo.
function pushbuttonGo_Callback(hObject, eventdata, handles)
% hObject    handle to pushbuttonGo (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

global SERIES
global SERIESINDEX
global SERIESTYPE
global SERIESSTAT

global TEMPX
global TEMPY

handles2=guidata(handles.baseFigure);
index=get(handles2.listbox1,'Value');
SRC=SERIES{index};

windowSize=str2num(get(handles.editWindowSize,'String'));
windowStep=str2num(get(handles.editWindowStep,'String'));

RES=calculateMSTWindow(SRC,windowSize,windowStep);

figure(handles.plotFigure);
plot(RES);

figure(handles.figure1);

SERIESINDEX=SERIESINDEX+1;
SERIES{SERIESINDEX}  =RES;
SERIESTYPE{SERIESINDEX}  =[char(SERIESTYPE{index}) ';WNDD'];
SERIESSTAT{SERIESINDEX}  =getStat(RES);
SERIESSTAT{SERIESINDEX}.fileName=SERIESSTAT{index}.fileName;
CD=get(handles2.listbox1,'String');
[CDm,CDn]=size(CD);
CD(CDm+1,:)='ĪźķīMST ';
set(handles2.listbox1,'String',CD);

% --- Executes on button press in checkboxLogY.
function checkboxLogY_Callback(hObject, eventdata, handles)
% hObject    handle to checkboxLogY (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of checkboxLogY

if get(hObject,'Value')==get(hObject,'Max')
    set(get(handles.plotFigure,'CurrentAxes'),'YScale','log');
else
    set(get(handles.plotFigure,'CurrentAxes'),'YScale','linear');
end

% --- Executes on button press in checkboxLogX.
function checkboxLogX_Callback(hObject, eventdata, handles)
% hObject    handle to checkboxLogX (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of checkboxLogX

if get(hObject,'Value')==get(hObject,'Max')
    set(get(handles.plotFigure,'CurrentAxes'),'XScale','log');
else
    set(get(handles.plotFigure,'CurrentAxes'),'XScale','linear');
end

% --- Executes during object creation, after setting all properties.
function editWindowSize_CreateFcn(hObject, eventdata, handles)
% hObject    handle to editWindowSize (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end

function editWindowSize_Callback(hObject, eventdata, handles)
% hObject    handle to editWindowSize (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of editWindowSize as text
%        str2double(get(hObject,'String')) returns contents of editWindowSize as a double


% --- Executes during object creation, after setting all properties.
function editWindowStep_CreateFcn(hObject, eventdata, handles)
% hObject    handle to editWindowStep (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end

function editWindowStep_Callback(hObject, eventdata, handles)
% hObject    handle to editWindowStep (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of editWindowStep as text
%        str2double(get(hObject,'String')) returns contents of editWindowStep as a double
